Learn R Programming

hR (version 0.3.0)

hierarchyStats: hierarchyStats

Description

The hierarchyStats function computes summary statistics and span of control metrics from a standard set of unique employee and supervisor identifiers (employee IDs, email addresses, etc.).

Usage

hierarchyStats(ee, supv)

Value

list

Arguments

ee

A vector containing unique identifiers for employees.

supv

A vector containing unique identifiers for supervisors. These values should be of the same type as the employee values.

Examples

Run this code

Run the code above in your browser using DataLab